{pkgs, ...}: {
  shell = {
    fish.enable = true;
    nushell.enable = false;
    oh-my-posh.enable = true;
  };

  console.yazi.enable = true;

  stylix.targets.fzf.enable = false;
  programs = {
    bat.enable = true;
    btop = {
      enable = true;
      settings.update_ms = 200;
    };
    eza.enable = true;
    fd.enable = true;
    fzf = {
      enable = true;
      defaultOptions = ["--color=16"];
    };
    pay-respects.enable = true;
    nix-index.enable = true;
    nix-index-database.comma.enable = true;
    gitui.enable = true;
    git = {
      enable = true;
      delta.enable = true;
      signing.format = "ssh";
      aliases = {
        cl = "clone";
        co = "checkout";
        pom = "push origin main";
      };
    };
    ripgrep.enable = true;
  };

  terminal = {
    ghostty.enable = true;
    kitty.enable = true;
  };

  editor = {
    helix.enable = true;
    neve.enable = true;
    zed.enable = true;
  };

  home.packages = with pkgs; [
    alejandra # nix formatter
    flatpak # flatpak cli
    trashy # trash cli
    procs # ps in rust
    ouch # archive manager in runt
    dust # du in rust
    fend # calc in rust
    moar # better pager
    tree # tree util
    rbw # bitwarden cli in rust
    pinentry-qt # pinentry for rbw
    vial # qmk keyboard configuring app
    waycheck # check wayland protocols
    virt-manager # libvirt gui
  ];
  systemd.user.settings.Manager.DefaultEnvironment.PAGER = "moar";
}
